Skip to contents

Plots the bootstrap distribution of the test statistic with the observed statistic and the rejection region highlighted.

Usage

# S3 method for class 'iv_test'
plot(x, ...)

Arguments

x

An object of class iv_test.

...

Further graphical arguments passed to graphics::hist.

Value

Invisibly returns x.